@@ -26,7 +26,9 @@ class KongAuth(BaseAuth):
                                   systemuser=current_app.config.get('LOGIN_USER_SYSTEMUSER', False),
                                   manageuser=current_app.config.get('LOGIN_USER_MANAGEUSER', False),
                                   manageuserid=current_app.config.get('LOGIN_USER_MANAGEUSER_ID'),
-                                  companyid=current_app.config.get('LOGIN_USER_COMPANYID',''))
+                                  companyid=current_app.config.get('LOGIN_USER_COMPANYID',''),
+                                  type=session.get('type', 'appuser')
+                                  )
             g.jwt = session.sid
             session.update({'uid':g.current_user.uid,'uname':g.current_user.uname,
                             'systemuser':g.current_user.systemuser,
@@ -70,7 +72,8 @@ class KongAuth(BaseAuth):
                 session.update(dict({'uid':g.user_id ,'uname':g.user_name,
                             'systemuser':False,
                             'manageuser':False,
-                            'manageuserid':''}))
+                            'manageuserid':'',
+                            'type':'appuser'}))
             else:
                 session.update(dict(mysession))
         g.current_user = User(uid=session.get('uid'),
@@ -78,7 +81,9 @@ class KongAuth(BaseAuth):
                               systemuser=session.get('systemuser', False),
                               manageuser=session.get('manageuser', False),
                               manageuserid=session.get('manageuserid'),
-                              companyid=session.get('companyid',''))
+                              companyid=session.get('companyid',''),
+                              type=session.get('type','appuser')
+                              )
         g.user_name = session.get('uname')
         g.user_id = session.get('uid')
 
